# Examples

## Cases from [10.1093/pnasnexus/pgae005](https://doi.org/10.1093/pnasnexus/pgae005)

* Poison equation in two dimensions: [`poisson`](poisson/)

* Inferring conductivity from temperature: [`heat`](heat/)
